@@ -1443,10 +1443,17 @@ def generate_html_new(report, output_path, customer_name='N/A'):
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
 
-    #Copy css files to output directory
+    # Copy css files to output directory
     copytree(templates_dir, output_dir, symlinks = True)
     os.remove(os.path.join(output_dir, 'risk-report-template-generic.html'))
 
+    # NOTE: I have deleted index_raw.html from the template folder but for
+    # some reason this file is still present on pypi server.
+    # TODO: delete next 3 lines when index_raw.html is removed from pypi package
+    index_raw = os.path.join(output_dir, 'index_raw.html')
+    if os.path.isfile(index_raw):
+        os.remove(index_raw)
+
     html_file = os.path.join(output_dir, 'index.html')
     current_time = datetime.now()
     dt_string = current_time.strftime("%B %d, %Y %H:%M:%S")
